@@ -257,35 +257,42 @@ class Types():
         }
     }
 
+    _SINGLE_ITEM_VALUES_LIST = [
+        {
+            "type": "object",
+            "required": [Props.ITEM_TYPE_STRING],
+            "properties": {
+                Props.ITEM_TYPE_STRING: {
+                    "type": "string"
+                }
+            }
+        },
+        {
+            "type": "object",
+            "required": [Props.ITEM_TYPE_NUMBER],
+            "properties": {
+                Props.ITEM_TYPE_NUMBER: {
+                    "type": "string"
+                }
+            }
+        },
+        {
+            "type": "object",
+            "required": [Props.ITEM_TYPE_BLOB],
+            "properties": {
+                Props.ITEM_TYPE_BLOB: {
+                    "type": "string"
+                }
+            }
+        },
+    ]
+
+    SINGLE_ITEM_VALUE = {
+        "oneOf": _SINGLE_ITEM_VALUES_LIST
+    }
+
     ITEM_VALUE = {
-        "oneOf": [
-            {
-                "type": "object",
-                "required": [Props.ITEM_TYPE_STRING],
-                "properties": {
-                    Props.ITEM_TYPE_STRING: {
-                        "type": "string"
-                    }
-                }
-            },
-            {
-                "type": "object",
-                "required": [Props.ITEM_TYPE_NUMBER],
-                "properties": {
-                    Props.ITEM_TYPE_NUMBER: {
-                        "type": "string"
-                    }
-                }
-            },
-            {
-                "type": "object",
-                "required": [Props.ITEM_TYPE_BLOB],
-                "properties": {
-                    Props.ITEM_TYPE_BLOB: {
-                        "type": "string"
-                    }
-                }
-            },
+        "oneOf": _SINGLE_ITEM_VALUES_LIST + [
             {
                 "type": "object",
                 "required": [Props.ITEM_TYPE_STRING_SET],
@@ -568,7 +575,7 @@ class Parser():
         elif single_value_type == models.AttributeType.ELEMENT_TYPE_NUMBER:
             return DECIMAL_CONTEXT.create_decimal(encoded_single_value)
         elif single_value_type == models.AttributeType.ELEMENT_TYPE_BLOB:
-            return base64.decodestring(encoded_single_value)
+            return base64.b64decode(encoded_single_value)
         else:
             assert False, "Value type wasn't recognized"
 
@@ -582,7 +589,7 @@ class Parser():
             return str(decoded_single_value)
         elif single_value_type == models.AttributeType.ELEMENT_TYPE_BLOB:
             assert isinstance(decoded_single_value, str)
-            return base64.encodestring(decoded_single_value)
+            return base64.b64encode(decoded_single_value)
         else:
             assert False, "Value type wasn't recognized"
 
