@@ -27,49 +27,6 @@ class MagnetoDBQueriesTestCase(MagnetoDBTestCase):
         super(MagnetoDBQueriesTestCase, self).setUp()
         self.tname = rand_name().replace('-', '')
 
-    @test.attr(type='negative')
-    def test_query_with_empty_key_cond(self):
-        self._create_test_table(self.smoke_attrs,
-                                self.tname,
-                                self.smoke_schema,
-                                wait_for_active=True)
-        item = self.build_smoke_item('forum1', 'subject2',
-                                     'message text', 'John', '10')
-        self.client.put_item(self.tname, item)
-        with self.assertRaises(exceptions.BadRequest):
-            self.client.query(table_name=self.tname,
-                              key_conditions={},
-                              consistent_read=True)
-
-    @test.attr(type=['Q-39', 'negative'])
-    def test_query_without_key_cond(self):
-        self._create_test_table(self.smoke_attrs,
-                                self.tname,
-                                self.smoke_schema,
-                                wait_for_active=True)
-        item = self.build_smoke_item('forum1', 'subject2',
-                                     'message text', 'John', '10')
-        self.client.put_item(self.tname, item)
-        with self.assertRaises(exceptions.BadRequest):
-            self.client.query(table_name=self.tname, consistent_read=True)
-
-    @test.attr(type=['Q-6', 'negative'])
-    def test_query_non_existent_table(self):
-        key_conditions = {
-            'forum': {
-                'attribute_value_list': [{'S': 'forum1'}],
-                'comparison_operator': 'EQ'
-            },
-            'subject': {
-                'attribute_value_list': [{'S': 'subject'}],
-                'comparison_operator': 'BEGINS_WITH'
-            }
-        }
-        with self.assertRaises(exceptions.NotFound):
-            self.client.query(table_name='non_existent_table',
-                              key_conditions=key_conditions,
-                              consistent_read=True)
-
     @test.attr(type='negative')
     def test_query_only_range_in_key_cond(self):
         self._create_test_table(self.smoke_attrs,
@@ -262,58 +219,6 @@ class MagnetoDBQueriesTestCase(MagnetoDBTestCase):
                               consistent_read=True,
                               select='COUNT')
 
-    @test.attr(type=['Q-22', 'negative'])
-    def test_query_attributes_to_get_select_empty(self):
-        self._create_test_table(self.smoke_attrs,
-                                self.tname,
-                                self.smoke_schema,
-                                wait_for_active=True)
-        self.put_smoke_item(self.tname, 'forum1', 'subject2',
-                            'message text', 'John', '10')
-        attributes_to_get = ['last_posted_by']
-        key_conditions = {
-            'forum': {
-                'attribute_value_list': [{'S': 'forum1'}],
-                'comparison_operator': 'EQ'
-            },
-            'subject': {
-                'attribute_value_list': [{'S': 'subject'}],
-                'comparison_operator': 'BEGINS_WITH'
-            }
-        }
-        with self.assertRaises(exceptions.BadRequest):
-            self.client.query(table_name=self.tname,
-                              key_conditions=key_conditions,
-                              attributes_to_get=attributes_to_get,
-                              consistent_read=True,
-                              select='')
-
-    @test.attr(type=['Q-23', 'negative'])
-    def test_query_attributes_to_get_select_incorrect(self):
-        self._create_test_table(self.smoke_attrs,
-                                self.tname,
-                                self.smoke_schema,
-                                wait_for_active=True)
-        self.put_smoke_item(self.tname, 'forum1', 'subject2',
-                            'message text', 'John', '10')
-        attributes_to_get = ['last_posted_by']
-        key_conditions = {
-            'forum': {
-                'attribute_value_list': [{'S': 'forum1'}],
-                'comparison_operator': 'EQ'
-            },
-            'subject': {
-                'attribute_value_list': [{'S': 'subject'}],
-                'comparison_operator': 'BEGINS_WITH'
-            }
-        }
-        with self.assertRaises(exceptions.BadRequest):
-            self.client.query(table_name=self.tname,
-                              key_conditions=key_conditions,
-                              attributes_to_get=attributes_to_get,
-                              consistent_read=True,
-                              select='INVALID')
-
     @test.attr(type=['Q-27', 'negative'])
     def test_query_attributes_to_get_empty(self):
         self._create_test_table(self.smoke_attrs,
@@ -373,51 +278,24 @@ class MagnetoDBQueriesTestCase(MagnetoDBTestCase):
                               key_conditions=key_conditions,
                               consistent_read=True)
 
-    @test.attr(type=['Q-108', 'negative'])
-    def test_query_key_cond_invalid_comparison(self):
-        self._query_key_cond_comparison_negative('N', '1', [{'N': '1'}], '%%')
-
-    @test.attr(type=['Q-131', 'negative'])
-    def test_query_key_cond_comparison_other_string(self):
-        self._query_key_cond_comparison_negative('N', '1', [{'N': '1'}], 'QQ')
-
-    @test.attr(type=['Q-129', 'negative'])
-    def test_query_key_cond_empty_comparison(self):
-        self._query_key_cond_comparison_negative('N', '1', [{'N': '1'}], '')
-
     @test.attr(type=['Q-113', 'negative'])
     def test_query_key_cond_lt_two_attrs(self):
         self._query_key_cond_comparison_negative('N', '1',
                                                  [{'N': '1'}, {'N': '2'}],
                                                  'LT')
 
-    @test.attr(type=['Q-114', 'negative'])
-    def test_query_key_cond_lt_set(self):
-        self._query_key_cond_comparison_negative('N', '1',
-                                                 [{'NS': ['1', '2']}], 'LT')
-
     @test.attr(type=['Q-110', 'negative'])
     def test_query_key_cond_le_two_attrs(self):
         self._query_key_cond_comparison_negative('N', '1',
                                                  [{'N': '1'}, {'N': '2'}],
                                                  'LE')
 
-    @test.attr(type=['Q-111', 'negative'])
-    def test_query_key_cond_le_set(self):
-        self._query_key_cond_comparison_negative('N', '1',
-                                                 [{'NS': ['1', '2']}], 'LE')
-
     @test.attr(type=['Q-116', 'negative'])
     def test_query_key_cond_ge_two_attrs(self):
         self._query_key_cond_comparison_negative('N', '1',
                                                  [{'N': '1'}, {'N': '2'}],
                                                  'GE')
 
-    @test.attr(type=['Q-117', 'negative'])
-    def test_query_key_cond_ge_set(self):
-        self._query_key_cond_comparison_negative('N', '1',
-                                                 [{'NS': ['1', '2']}], 'GE')
-
     @test.attr(type=['Q-119', 'negative'])
     def test_query_key_cond_gt_two_attrs(self):
         self._query_key_cond_comparison_negative('N', '1',
@@ -430,17 +308,6 @@ class MagnetoDBQueriesTestCase(MagnetoDBTestCase):
                                                  [{'S': 'start'},
                                                   {'S': 'end'}], 'BEGINS_WITH')
 
-    @test.attr(type=['Q-124', 'negative'])
-    def test_query_key_cond_begins_with_set(self):
-        self._query_key_cond_comparison_negative('S', 'startend',
-                                                 [{'SS': ['start', 'end']}],
-                                                 'BEGINS_WITH')
-
-    @test.attr(type=['Q-120', 'negative'])
-    def test_query_key_cond_gt_set(self):
-        self._query_key_cond_comparison_negative('N', '1',
-                                                 [{'NS': ['1', '2']}], 'GT')
-
     @test.attr(type=['Q-122', 'negative'])
     def test_query_key_cond_begins_with_bad_field(self):
         self._query_key_cond_comparison_negative('S', 'startend',
@@ -460,12 +327,6 @@ class MagnetoDBQueriesTestCase(MagnetoDBTestCase):
         self._query_key_cond_comparison_negative('S', '1', [{'S': '1'}],
                                                  'BETWEEN')
 
-    @test.attr(type=['Q-128', 'negative'])
-    def test_query_key_cond_between_set(self):
-        self._query_key_cond_comparison_negative('S', '1',
-                                                 [{'SS': ['0', '2']}],
-                                                 'BETWEEN')
-
     @test.attr(type=['Q-11'])
     def test_query_table_name_query_upper_case(self):
         # NOTE(aostapenko) Check if table name is case sensitive in dynamodb
@@ -490,117 +351,6 @@ class MagnetoDBQueriesTestCase(MagnetoDBTestCase):
                                           key_conditions=key_conditions)
         self.assertTrue(body['count'] > 0)
 
-    @test.attr(type=['Q-16', 'negative'])
-    def test_query_attributes_to_get_empty_values(self):
-        self._create_test_table(self.smoke_attrs,
-                                self.tname,
-                                self.smoke_schema,
-                                wait_for_active=True)
-        self.put_smoke_item(self.tname, 'forum1', 'subject2',
-                            'message text', 'John', '10')
-        attributes_to_get = ['']
-        key_conditions = {
-            'forum': {
-                'attribute_value_list': [{'S': 'forum1'}],
-                'comparison_operator': 'EQ'
-            },
-            'subject': {
-                'attribute_value_list': [{'S': 'subject'}],
-                'comparison_operator': 'BEGINS_WITH'
-            }
-        }
-        with self.assertRaises(exceptions.BadRequest):
-            self.client.query(table_name=self.tname,
-                              key_conditions=key_conditions,
-                              attributes_to_get=attributes_to_get,
-                              consistent_read=True)
-
-    @test.attr(type=['Q-40_1', 'negative'])
-    def test_query_key_cond_invalid_type_ss(self):
-        self._create_test_table(self.smoke_attrs,
-                                self.tname,
-                                self.smoke_schema,
-                                wait_for_active=True)
-        key_conditions = {
-            'forum': {
-                'attribute_value_list': [{'SS': 'forum1'}],
-                'comparison_operator': 'EQ'
-            },
-            'subject': {
-                'attribute_value_list': [{'S': 'subject'}],
-                'comparison_operator': 'BEGINS_WITH'
-            }
-        }
-        with self.assertRaises(exceptions.BadRequest):
-            self.client.query(table_name=self.tname,
-                              key_conditions=key_conditions,
-                              consistent_read=True)
-
-    @test.attr(type=['Q-40_2', 'negative'])
-    def test_query_key_cond_invalid_type_other(self):
-        self._create_test_table(self.smoke_attrs,
-                                self.tname,
-                                self.smoke_schema,
-                                wait_for_active=True)
-        key_conditions = {
-            'forum': {
-                'attribute_value_list': [{'INVALID': 'forum1'}],
-                'comparison_operator': 'EQ'
-            },
-            'subject': {
-                'attribute_value_list': [{'S': 'subject'}],
-                'comparison_operator': 'BEGINS_WITH'
-            }
-        }
-        with self.assertRaises(exceptions.BadRequest):
-            self.client.query(table_name=self.tname,
-                              key_conditions=key_conditions,
-                              consistent_read=True)
-
-    @test.attr(type=['Q-45', 'negative'])
-    def test_query_consistent_read_invalid_value(self):
-        self._create_test_table(self.smoke_attrs,
-                                self.tname,
-                                self.smoke_schema,
-                                wait_for_active=True)
-        key_conditions = {
-            'forum': {
-                'attribute_value_list': [{'S': 'forum1'}],
-                'comparison_operator': 'EQ'
-            },
-            'subject': {
-                'attribute_value_list': [{'S': 'subject'}],
-                'comparison_operator': 'BEGINS_WITH'
-            }
-        }
-        with self.assertRaises(exceptions.BadRequest):
-            self.client.query(table_name=self.tname,
-                              key_conditions=key_conditions,
-                              consistent_read='INVALID')
-
-    @test.attr(type=['Q-62', 'negative'])
-    def test_query_exclusive_set(self):
-        self._create_test_table(self.smoke_attrs,
-                                self.tname,
-                                self.smoke_schema,
-                                wait_for_active=True)
-        key_conditions = {
-            'forum': {
-                'attribute_value_list': [{'S': 'forum1'}],
-                'comparison_operator': 'EQ'
-            },
-            'subject': {
-                'attribute_value_list': [{'S': 'subject'}],
-                'comparison_operator': 'BEGINS_WITH'
-            }
-        }
-        exclusive = {'forum': {'SS': ['one', 'two']}}
-        with self.assertRaises(exceptions.BadRequest):
-            self.client.query(table_name=self.tname,
-                              key_conditions=key_conditions,
-                              exclusive_start_key=exclusive,
-                              consistent_read=True)
-
     @test.attr(type=['Q-64', 'negative'])
     def test_query_exclusive_incorrect(self):
         self._create_test_table(self.smoke_attrs,
@@ -702,32 +452,6 @@ class MagnetoDBQueriesTestCase(MagnetoDBTestCase):
                               index_name=index_name,
                               consistent_read=True)
 
-    @test.attr(type=['Q-74', 'negative'])
-    def test_query_index_empty_index_name(self):
-        self._create_test_table(self.smoke_attrs + self.index_attrs,
-                                self.tname,
-                                self.smoke_schema,
-                                self.smoke_lsi,
-                                wait_for_active=True)
-        self.put_smoke_item(self.tname, 'forum1', 'subject2',
-                            'message text', 'John', '10')
-        index_name = ''
-        key_conditions = {
-            'forum': {
-                'attribute_value_list': [{'S': 'forum1'}],
-                'comparison_operator': 'EQ'
-            },
-            'last_posted_by': {
-                'attribute_value_list': [{'S': 'John'}],
-                'comparison_operator': 'EQ'
-            }
-        }
-        with self.assertRaises(exceptions.BadRequest):
-            self.client.query(table_name=self.tname,
-                              key_conditions=key_conditions,
-                              index_name=index_name,
-                              consistent_read=True)
-
     @test.attr(type=['Q-83'])
     def test_query_limit_0_items_3(self):
         # NOTE(aostapenko) Needs verification in dynamodb
@@ -776,8 +500,8 @@ class MagnetoDBQueriesTestCase(MagnetoDBTestCase):
         with self.assertRaises(exceptions.BadRequest):
             self.client.query(table_name=self.tname,
                               key_conditions=key_conditions,
-                              scan_index_forward=False,
-                              consistent_read='INVALID')
+                              scan_index_forward='other',
+                              consistent_read=True)
 
     @test.attr(type=['Q-90', 'negative'])
     def test_query_scan_index_empty(self):
@@ -800,8 +524,8 @@ class MagnetoDBQueriesTestCase(MagnetoDBTestCase):
         with self.assertRaises(exceptions.BadRequest):
             self.client.query(table_name=self.tname,
                               key_conditions=key_conditions,
-                              scan_index_forward=False,
-                              consistent_read='')
+                              scan_index_forward='',
+                              consistent_read=True)
 
     @test.attr(type=['Q-94'])
     def test_query_select_all_projected(self):
@@ -840,78 +564,6 @@ class MagnetoDBQueriesTestCase(MagnetoDBTestCase):
         self.assertEqual(body['count'], 1)
         self.assertEqual(len(body['items'][0]), 3)
 
-    @test.attr(type=['Q-98', 'negative'])
-    def test_query_select_empty(self):
-        self._create_test_table(self.smoke_attrs,
-                                self.tname,
-                                self.smoke_schema,
-                                wait_for_active=True)
-        key_conditions = {
-            'forum': {
-                'attribute_value_list': [{'S': 'forum1'}],
-                'comparison_operator': 'EQ'
-            },
-            'subject': {
-                'attribute_value_list': [{'S': 'subject'}],
-                'comparison_operator': 'BEGINS_WITH'
-            }
-        }
-        with self.assertRaises(exceptions.BadRequest):
-            self.client.query(table_name=self.tname,
-                              key_conditions=key_conditions,
-                              consistent_read=True,
-                              select='')
-
-    @test.attr(type=['Q-99', 'negative'])
-    def test_query_select_invalid(self):
-        self._create_test_table(self.smoke_attrs,
-                                self.tname,
-                                self.smoke_schema,
-                                wait_for_active=True)
-        key_conditions = {
-            'forum': {
-                'attribute_value_list': [{'S': 'forum1'}],
-                'comparison_operator': 'EQ'
-            },
-            'subject': {
-                'attribute_value_list': [{'S': 'subject'}],
-                'comparison_operator': 'BEGINS_WITH'
-            }
-        }
-        with self.assertRaises(exceptions.BadRequest):
-            self.client.query(table_name=self.tname,
-                              key_conditions=key_conditions,
-                              consistent_read=True,
-                              select='INVALID')
-
-    @test.attr(type=['Q-103'])
-    def test_query_one_key_cond_eq_ss(self):
-        attrs = [
-            {'attribute_name': 'forum', 'attribute_type': 'S'},
-            {'attribute_name': 'subject', 'attribute_type': 'S'}
-        ]
-        schema = [
-            {'attribute_name': 'forum', 'key_type': 'HASH'},
-            {'attribute_name': 'subject', 'key_type': 'RANGE'}
-        ]
-        self._create_test_table(attrs, self.tname, schema,
-                                wait_for_active=True)
-        item = {
-            "forum": {"S": '1'},
-            "subject": {"S": '1'}
-        }
-        self.client.put_item(self.tname, item)
-        key_conditions = {
-            'forum': {
-                'attribute_value_list': [{'SS': ['1', '2']}],
-                'comparison_operator': 'EQ'
-            }
-        }
-        with self.assertRaises(exceptions.BadRequest):
-            self.client.query(table_name=self.tname,
-                              key_conditions=key_conditions,
-                              consistent_read=True)
-
     @test.attr(type=['Q-104'])
     def test_query_one_key_cond_eq_s_n(self):
         attrs = [
@@ -997,28 +649,3 @@ class MagnetoDBQueriesTestCase(MagnetoDBTestCase):
             self.client.query(table_name=self.tname,
                               key_conditions=key_conditions,
                               consistent_read=True)
-
-    @test.attr(type=['Q-16'])
-    def test_query_attributes_to_get_incorrect_attr_name(self):
-        self._create_test_table(self.smoke_attrs,
-                                self.tname,
-                                self.smoke_schema,
-                                wait_for_active=True)
-        self.put_smoke_item(self.tname, 'forum1', 'subject2',
-                            'message text', 'John', '10')
-        attributes_to_get = ['%$&']
-        key_conditions = {
-            'forum': {
-                'attribute_value_list': [{'S': 'forum1'}],
-                'comparison_operator': 'EQ'
-            },
-            'subject': {
-                'attribute_value_list': [{'S': 'subject'}],
-                'comparison_operator': 'BEGINS_WITH'
-            }
-        }
-        with self.assertRaises(exceptions.BadRequest):
-            self.client.query(table_name=self.tname,
-                              key_conditions=key_conditions,
-                              attributes_to_get=attributes_to_get,
-                              consistent_read=True)
