@@ -77,7 +77,7 @@ class MagnetoDBTestCase(tempest.test.BaseTestCase):
         for key in trash_keys:
             (function, pos_args, kw_args) = cls._resource_trash_bin[key]
             try:
-                LOG.debug("Cleaning up: %s" %
+                LOG.debug("Cleaning up: %s",
                           friendly_function_call_str(function, *pos_args,
                                                      **kw_args))
                 function(*pos_args, **kw_args)
@@ -88,7 +88,7 @@ class MagnetoDBTestCase(tempest.test.BaseTestCase):
                 del cls._resource_trash_bin[key]
         super(MagnetoDBTestCase, cls).tearDownClass()
         if fail_count:
-            LOG.error('%s cleanUp operation failed' % fail_count)
+            LOG.error('%s cleanUp operation failed', fail_count)
 
     @classmethod
     def addResourceCleanUp(cls, function, *args, **kwargs):
@@ -179,17 +179,17 @@ class MagnetoDBTestCase(tempest.test.BaseTestCase):
                 new_items.append(item)
         return new_items
 
-    def _create_test_table(self, attr_def, tname, *args, **kwargs):
+    def _create_test_table(self, attr_def, table_name, *args, **kwargs):
         cleanup = kwargs.pop('cleanup', True)
         wait_for_active = kwargs.pop('wait_for_active', False)
         headers, body = self.client.create_table(attr_def,
-                                                 tname,
+                                                 table_name,
                                                  *args,
                                                  **kwargs)
         if cleanup:
-            self.addResourceCleanUp(self.client.delete_table, tname)
+            self.addResourceCleanUp(self.client.delete_table, table_name)
         if wait_for_active:
-            self.wait_for_table_active(tname)
+            self.wait_for_table_active(table_name)
 
         return headers, body
 
